@@ -43,6 +43,7 @@ int parse_rfc_kwargs( PyObject* kwargs, Py_ssize_t len, Rainflow *rf, Rainflow::
     int         use_astm        =  0;  // false
     int         lc_method       =  0;  // Count rising slopes only
     int         flags           =  Rainflow::RFC_FLAGS_DEFAULT;
+    int         auto_resize     =  0;  // false
     int         spread_damage   =  Rainflow::RFC_SD_TRANSIENT_23c;
     PyObject   *wl              =  NULL;
     double      wl_sd           =  1e3, wl_nd = 1e7, 
@@ -51,16 +52,17 @@ int parse_rfc_kwargs( PyObject* kwargs, Py_ssize_t len, Rainflow *rf, Rainflow::
     *res_method = Rainflow::RFC_RES_REPEATED;
 
     char* kw[] = {"class_width", "class_count", "class_offset", 
-                  "hysteresis","residual_method", "enforce_margin", 
+                  "hysteresis","residual_method", "enforce_margin", "auto_resize",
                   "use_HCM", "use_ASTM", "spread_damage", "lc_method", "wl", NULL};
 
-    if( !PyArg_ParseTupleAndKeywords( empty, kwargs, "d|iddiiiiiiO", kw,
+    if( !PyArg_ParseTupleAndKeywords( empty, kwargs, "d|iddiiiiiiiO", kw,
                                       &class_width,
                                       &class_count,
                                       &class_offset,
                                       &hysteresis,
                                        res_method,
                                       &enforce_margin,
+                                      &auto_resize,
                                       &use_hcm,
                                       &use_astm,
                                       &spread_damage,
@@ -120,33 +122,54 @@ int parse_rfc_kwargs( PyObject* kwargs, Py_ssize_t len, Rainflow *rf, Rainflow::
         if( hysteresis < 0 ) hysteresis = class_width;
     }
 
-    // lc_method
-    flags &= ~Rainflow::RFC_FLAGS_COUNT_LC;
-
-    switch( lc_method )
-    {
-        case 0:
-            flags |= Rainflow::RFC_FLAGS_COUNT_LC_UP;
-            break;
-
-        case 1:
-            flags |= Rainflow::RFC_FLAGS_COUNT_LC_DN;
-            break;
-
-        case 2:
-            flags |= Rainflow::RFC_FLAGS_COUNT_LC;
-            break;
-
-        default:
-            PyErr_SetString( PyExc_RuntimeError, "Parameter 'lc_method' must be in range 0 to 2!" );
-            return 0;
-    }
-
     if( !rf->init( class_count, class_width, class_offset, hysteresis, (Rainflow::rfc_flags_e)flags ) )
     {
         PyErr_Format( PyExc_RuntimeError, "Rainflow initialization error (%s)", rfc_err_str( rf->error_get() ) );
         return 0;
     }
+    else
+    {
+        rf->flags_get( &flags );
+
+        // lc_method
+        flags &= ~Rainflow::RFC_FLAGS_COUNT_LC;
+
+        switch( lc_method )
+        {
+            case 0:
+                flags |= Rainflow::RFC_FLAGS_COUNT_LC_UP;
+                break;
+
+            case 1:
+                flags |= Rainflow::RFC_FLAGS_COUNT_LC_DN;
+                break;
+
+            case 2:
+                flags |= Rainflow::RFC_FLAGS_COUNT_LC;
+                break;
+
+            default:
+                PyErr_SetString( PyExc_RuntimeError, "Parameter 'lc_method' must be 0, 1 or 2!" );
+                return 0;
+        }
+
+        switch( auto_resize )
+        {
+            case 0:
+                break;
+
+            case 1:
+                flags &= ~Rainflow::RFC_FLAGS_AUTORESIZE;
+                flags |=  Rainflow::RFC_FLAGS_AUTORESIZE;
+                break;
+
+            default:
+                PyErr_SetString( PyExc_RuntimeError, "Parameter 'auto_resize' must be 0 or 1!" );
+                return 0;
+        }
+
+        rf->flags_set( flags, /* debugging */ false, /* overwrite */ true );
+    }
 
     if( !rf->wl_init_modified( wl_sd, wl_nd, wl_k, wl_k2 ) )
     {
@@ -403,36 +426,50 @@ static PyObject* rfc( PyObject *self, PyObject *args, PyObject *kwargs )
     Rainflow rf;
     Rainflow::rfc_res_method res_method;
     Py_ssize_t len;
+    bool ok = false;
 
-    if( !parse_rfc_input_series( args, &arr_data, &data, &len ) )
+    do
     {
-        goto fail;
-    }
+        if( !parse_rfc_input_series( args, &arr_data, &data, &len ) )
+        {
+            break;
+        }
 
-    if( !parse_rfc_kwargs( kwargs, len, &rf, &res_method ) )
+        if( !parse_rfc_kwargs( kwargs, len, &rf, &res_method ) )
+        {
+            break;
+        }
+
+        if( !do_rainflow( &rf, data, len, res_method ) )
+        {
+            break;
+        }
+
+        if( !prepare_results( &rf, res_method, &ret ) )
+        {
+            break;
+        }
+        
+        ok = true;
+    }
+    while(0);
+
+
+    if( !ok && ret )
     {
-        goto fail;
+        Py_DECREF( ret );
+        ret = NULL;
     }
+    
+    rf.deinit();
 
-    if( !do_rainflow( &rf, data, len, res_method ) )
-    {
-        goto fail;
-    }
-
-    if( !prepare_results( &rf, res_method, &ret ) )
-    {
-        goto fail;
-    }
-
-    return ret;
-
-fail:
     if( arr_data && data )
     {
         Py_DECREF( arr_data );
         PyArray_Free( (PyObject*)arr_data, (void*)data );
     }
-    return NULL;
+
+    return ret;
 }
 
 
